@@ -66,6 +66,7 @@ class Model:
     SUBSCRIBE = False  # type: bool
 
     def __init__(self, element: "Element"):
+        self.__tid = 0
         self.element = element
 
         self.logger = self.element.logger.getChild("%s" % type(self).__name__)
@@ -79,6 +80,11 @@ class Model:
         assert self.MODEL_ID[1] is not None, "A model has to have ID!"
         self.configuration = ModelConfig(bindings=[], subscriptions=[])
 
+    def tid(self) -> int:
+        tid = self.__tid
+        self.__tid = (tid + 1) % 255
+        return tid
+
     def __str__(self):
         if self.MODEL_ID[0] is None:
             return "<Model %04x>" % self.MODEL_ID[1]
@@ -288,10 +294,10 @@ class Model:
         self, destination: int, remote: bool, net_index: int, data: bytes
     ):
         self.logger.debug(
-            "Sending: %s - > %04x [remote %s, net_index %d] %s",
+            "Sending: %s -> %04x [remote %s, net_index %d] %s",
             self.element.path,
-            remote,
             destination,
+            remote,
             net_index,
             data.hex(),
         )
